Skip to content
KitploitKITPLOIT
HerramientasExploitsBlog
Log in
Enviar
HerramientasExploitsBlog
Enviar

¡Herramientas de Hacking, PenTest y Ciberseguridad para tu Arsenal de Seguridad!

Kitploit es un directorio de herramientas de hacking, ciberseguridad y pentesting. Descubre las últimas actualizaciones de proyectos para encontrar vulnerabilidades, analizar sistemas, automatizar pruebas y fortalecer tu seguridad.

··Feeds·Contacto·Privacidad·© 2026 Kitploit

Directorio de Herramientas

Categorías

Ver todas las categorías
Loading categories
intelspy — Realizar escaneos automatizados de reconocimiento de red | Kitploit
Herramientas/GitHubGitHub/maldevel/intelspy
ReconocimientoEscáneres de VulnerabilidadesMapeo de RedesEscaneo de PuertosRecopilación de InformaciónPruebas de Penetración
GitHubmaldevel/intelspy

intelspy

Realizar escaneos automatizados de reconocimiento de red

Ver Repositorio
2374516hace 5 añosRevisado por Kitploit

Más Populares

Ver todos →

Descubre las herramientas más usadas por nuestra comunidad.

Explora todas las herramientas

Explora nuestra colección de herramientas

Ver todas las herramientas →
Compartir

Texto alternativo

Realiza escaneos automatizados de reconocimiento de red para recopilar inteligencia de red.

IntelSpy es una herramienta de inteligencia de red multi-hilo que realiza enumeración automatizada de servicios de red. Lleva a cabo escaneos de detección de hosts activos, escaneos de puertos, escaneos de enumeración de servicios, escaneos de contenido web, ataques de fuerza bruta, búsquedas detalladas de exploits fuera de línea y más.

La herramienta también lanzará escaneos de enumeración adicionales para cada servicio detectado utilizando diferentes herramientas.


Características

  • Escanea múltiples objetivos en forma de direcciones IP, rangos IP (notación CIDR) y nombres de host resolubles.
  • Escanea objetivos de manera concurrente.
  • Detecta hosts activos en un rango IP (CIDR) de red.
  • Perfiles de escaneo de puertos personalizables y comandos de enumeración de servicios.
  • Crea una estructura de directorios para la recopilación de resultados e informes.
  • Registra cada comando ejecutado.
  • Genera scripts de shell que contienen comandos para ejecutar manualmente.
  • Extrae información importante en formato txt y markdown para su posterior revisión.
  • Almacena datos en una base de datos SQLite.
  • Genera un informe HTML.

Requisitos

  • Python 3 (sudo apt install python3)
  • Linux (preferiblemente Kali Linux o cualquier otra distribución de hacking que contenga las herramientas siguientes.)
    • https://www.kali.org/downloads/
  • toml (https://github.com/toml-lang/toml)
  • seclists (https://github.com/danielmiessler/SecLists)
  • curl (prerrequisito) (sudo apt install curl)
  • enum4linux (prerrequisito) (sudo apt install enum4linux)
  • gobuster (prerrequisito) (sudo apt install gobuster)
  • hydra (opcional) (sudo apt install hydra)
  • ldapsearch (opcional) (sudo apt install ldap-utils)
  • medusa (opcional) (sudo apt install medusa)
  • nbtscan (prerrequisito) (sudo apt install nbtscan)
  • nikto (prerrequisito) (sudo apt install nikto)
  • nmap (prerrequisito) (sudo apt install nmap)
  • onesixtyone (prerrequisito) (sudo apt install onesixtyone)
  • oscanner (opcional) (sudo apt install oscanner)
  • pandoc (prerrequisito) (sudo apt install pandoc)
  • patator (opcional) (sudo apt install patator)
  • showmount (prerrequisito) (sudo apt install nfs-common)
  • smbclient (prerrequisito) (sudo apt install smbclient)
  • smbmap (prerrequisito) (sudo apt install smbmap)
  • smtp-user-enum (prerrequisito) (sudo apt install smtp-user-enum)
  • snmpwalk (prerrequisito) (sudo apt install snmp)
  • sslscan (prerrequisito) (sudo apt install sslscan)
  • svwar (prerrequisito) (sudo apt install sipvicious)
  • tnscmd10g (prerrequisito) (sudo apt install tnscmd10g)
  • whatweb (prerrequisito) (sudo apt install whatweb)
  • wkhtmltoimage (prerrequisito) (sudo apt install wkhtmltopdf)
  • wpscan (opcional) (sudo apt install wpscan)
pip3 install -r requirements.txt

Uso

$ python3 intelspy.py -h

 ___               __        
  |  ._ _|_  _  | (_  ._     
 _|_ | | |_ (/_ | __) |_) \/ 
                      |   /  
                                
IntelSpy v2.0 - Perform automated network reconnaissance scans to gather network intelligence.
IntelSpy is an open source tool licensed under GPLv3.
Written by: @maldevel | Logisek ICT
Web: https://logisek.com | https://pentest-labs.com
Project: https://github.com/maldevel/intelspy


usage: intelspy.py [-h] [-ts TARGET_FILE] -p PROJECT_NAME -w WORKING_DIR
                   [--exclude <host1[,host2][,host3],...>] [-s SPEED]
                   [-ct <number>] [-cs <number>] [--profile PROFILE_NAME]
                   [--livehost-profile LIVEHOST_PROFILE_NAME]
                   [--heartbeat HEARTBEAT] [-v]
                   [targets [targets ...]]

positional arguments:
  targets               IP addresses (e.g. 10.0.0.1), CIDR notation (e.g.
                        10.0.0.1/24), or resolvable hostnames (e.g.
                        example.com) to scan.

optional arguments:
  -h, --help            show this help message and exit
  -ts TARGET_FILE, --targets TARGET_FILE
                        Read targets from file.
  -p PROJECT_NAME, --project-name PROJECT_NAME
                        project name
  -w WORKING_DIR, --working-dir WORKING_DIR
                        working directory
  --exclude <host1[,host2][,host3],...>
                        exclude hosts/networks
  -s SPEED, --speed SPEED
                        0-5, set timing template (higher is faster) (default:
                        4)
  -ct <number>, --concurrent-targets <number>
                        The maximum number of target hosts to scan
                        concurrently. Default: 5
  -cs <number>, --concurrent-scans <number>
                        The maximum number of scans to perform per target
                        host. Default: 10
  --profile PROFILE_NAME
                        The port scanning profile to use (defined in port-
                        scan-profiles.toml). Default: default
  --livehost-profile LIVEHOST_PROFILE_NAME
                        The live host scanning profile to use (defined in
                        live-host-scan-profiles.toml). Default: default
  --heartbeat HEARTBEAT
                        Specifies the heartbeat interval (in seconds) for task
                        status messages. Default: 60
  -v, --verbose         Enable verbose output. Repeat for more verbosity (-v,
                        -vv, -vvv).

Ejemplos de uso

Escaneo de un solo objetivo

sudo python3 intelspy.py -p MyProjectName -w /home/user/pt/projects/ 192.168.10.15
sudo python3 intelspy.py -p MyProjectName -w /home/user/pt/projects/ 192.168.10.15 -v
sudo python3 intelspy.py -p MyProjectName -w /home/user/pt/projects/ 192.168.10.15 -vv
sudo python3 intelspy.py -p MyProjectName -w /home/user/pt/projects/ 192.168.10.15 -vvv

Escaneo de un nombre de host

sudo python3 intelspy.py -p MyProjectName -w /home/user/pt/projects/ example.com

Escaneo de un rango de red (CIDR)

sudo python3 intelspy.py -p MyProjectName -w /home/user/pt/projects/ 192.168.10.0/24

Escaneo de múltiples objetivos (separados por comas)

sudo python3 intelspy.py -p MyProjectName -w /home/user/pt/projects/ 192.168.10.15 192.168.10.0/24 example.com

Escaneo de objetivos desde un archivo

sudo python3 intelspy.py -p MyProjectName -w /home/user/pt/projects/ -ts /home/user/targets.txt

Excluyendo un host

sudo python3 intelspy.py -p MyProjectName -w /home/user/pt/projects/ --exclude 192.168.10.9 192.168.10.0/24

Excluyendo varios hosts

sudo python3 intelspy.py -p MyProjectName -w /home/user/pt/projects/ --exclude 192.168.10.9,192.168.10.24 192.168.10.0/24

Créditos

Comencé a trabajar en IntelSpy cuando descubrí AutoRecon. En lugar de reinventar la rueda, IntelSpy es el resultado de fusionar IntelSpy con las mejores características de AutoRecon para crear una herramienta de reconocimiento de red adecuada para compromisos de Pruebas de Penetración.Texto alternativo

Realiza escaneos automatizados de reconocimiento de red para recopilar inteligencia de red.

Descargar herramienta